@@ -8,7 +8,7 @@ use File::HomeDir::Darwin ();
 
 use vars qw{$VERSION @ISA};
 BEGIN {
-	$VERSION = '0.95';
+	$VERSION = '0.97';
 	@ISA     = 'File::HomeDir::Darwin';
 
 	# Load early if in a forking environment and we have
@@ -116,13 +116,13 @@ sub _find_folder {
 
 	require Mac::SystemDirectory;
 	my $folder = Mac::SystemDirectory::FindDirectory($name);
-	return unless defined $folder;
+	return undef unless defined $folder;
 
 	unless ( -d $folder ) {
 		# Make sure that symlinks resolve to directories.
-		return unless -l $folder;
+		return undef unless -l $folder;
 		my $dir = readlink $folder or return;
-		return unless -d $dir;
+		return undef unless -d $dir;
 	}
 
 	return Cwd::abs_path($folder);
